==> applet-service-2.0.2-20210622.105941-3-sources.jar: com/bizvane/appletservice/interfaces/IntegrationShopService.java <==
package com.bizvane.appletservice.interfaces;

import com.alibaba.fastjson.JSONObject;
import com.bizvane.appletservice.models.vo.*;
import com.bizvane.mktcenterservice.models.vo.CouponRecordVO;
import com.bizvane.utils.responseinfo.ResponseData;

import java.io.IOException;
import java.util.Map;

/**
 * 积分商城
 *
 * @author gs
 * @date
 */
public interface IntegrationShopService {
    /**
     * 积分商城首页
     *
     * @param
     * @return
     **/
    ResponseData shopHomePage(String sysBrandId, String menberCode);

    ResponseData<ShopHomePageVo> getHomePageMemberInfo(String memberCode, Long sysBrandId);

    /**
     * 全部商品展示
     *
     * @param
     * @return
     **/
    ResponseData fullMerchandiseDisplay(AllMerchandiseVo allMerchandiseVo);

    /**
     * 商品详情
     *
     * @param
     * @return
     **/
    ResponseData commodityDetails(String hostId);

    /**
     * 分类商品入口
     *
     * @param
     * @return
     **/
    ResponseData classifiedGoods(classifiedGoodsVo classifiedGoodsVo);
    /**
     * 分类商品列表
     *
     * @param
     * @return
     **/
    ResponseData tailForClassifiedGoods(AllMerchandiseVo allMerchandiseVo);

    /**
     * 生成订单
     *
     * @param
     * @return
     **/
    ResponseData generateOrder(ConfirmGoodsVo confirmGoodsVo);

    /**
     * 效验订单生成
     *
     * @param
     * @return
     **/
    ResponseData inventoryStatus(ConfirmGoodsVo confirmGoodsVo);

    /**
     * 增加收货地址
     *
     * @param
     * @return
     **/
    ResponseData increaseReceivingAddress(UserAddressPutVo userAddressPutVo);

    /**
     * 编辑收货地址
     *
     * @param
     * @return
     **/
    ResponseData editReceivingAddress(UserAddressPutVo userAddressPutVo);

    /**
     * 删除收货地址
     *
     * @param
     * @return
     **/
    ResponseData eliminateReceivingAddress(UserAddressPutVo userAddressPutVo);

    /**
     * 地址查询
     *
     * @param
     * @return
     **/
    ResponseData  addressuery(String memberCode);

    /**
     * 订单列表
     *
     * @param
     * @return
     **/
    ResponseData fullOrderDisplay(String sysBrandId, String orderStatus, String memberCode,Integer pageNum,Integer pageSize);


    /**
     * (旧版)订单列表
     *
     * @param
     * @return
     **/
    ResponseData fullOrderDisplay(String sysBrandId, String orderStatus, String memberCode);

    /**
     * 查看订单
     *
     * @param
     * @return
     **/
    ResponseData viewOrder(String orderId);
    /**
     * 优惠券
     *
     * @param
     * @return
     **/
    ResponseData fullCouponDisplay(CouponRecordVO couponRecordVO);
    /**
     * 优惠券订单详情
     *
     * @param
     * @return
     **/
    ResponseData tailForFullCouponDisplay(Long convertCouponRecordId,String memberCode);


    /**
     * 获取积分
     *
     * @param
     * @return
     **/
    ResponseData integralAcquisition(String sysBrandId);

    /**
     * 门店自提
     *
     * @param
     * @return
     **/
    ResponseData storeSelfMention();
    /**
     * 物流公司列表
     *
     * @param
     * @return
     **/
    ResponseData logisticsCompanyGroup();
    /**
     * 查看物流
     *
     * @param
     * @return
     **/
    ResponseData displayLogistics(String companyCode,String num,String phone);

    /**
     * 申请退货提交
     *
     * @param
     * @return
     **/
    ResponseData applyeturnSubmission(ReturnGoodsVo returnGoodsVo);

    /**
     * 申请退货添加物流
     *
     * @param
     * @return
     **/
    ResponseData applyeturnNotSubmitted(RefundLogisticsVo refundLogisticsVo);
    /**
     * 获取退货说明
     *
     * @param
     * @return
     **/
    ResponseData instructions(String sysBrandId);

    /**
     * 获取基础配置
     * @param merchantId
     * @return
     */
    ResponseData getConfig(Integer merchantId) throws IOException;

    void setIntegralConfig2Redis(Map<String, Object> map, Integer merchantId) ;

    ResponseData getAllOrdersPages(int pageNum, int pageSize, Integer sysBrandId, String memberCode);

    /**
     * 支付
     * @param ordersId
     * @return
     */
    ResponseData  payment(Integer ordersId);

    /**
     * 支付券
     * @param convertCouponRecordId
     * @return
     */
    ResponseData  paymentWithCoupon(Integer convertCouponRecordId,String bizvaneSessionId);

    /**
     * 支付成功
     * @param convertCouponRecordId
     * @return
     */
    ResponseData  payCouponSuccess(Integer convertCouponRecordId);

    ResponseData getFeight(IntegralOrderFeightVO integralOrderFeightVO);

    ResponseData getIntegralClassifyQRCord(IntegralQRCodeRequestVO integralQRCodeRequestVO);
    /**
    * 获取首页轮播图,分类和券图
    * */
    ResponseData<ShopHomePageVo> getHomePageRotationChart(String sysBrandId);
    /**
     * 获取首页热门商品
     * */
    ResponseData<JSONObject> getHomePageHotCommodity(IntegralShopGetHomePageHotCommodityRequestVO requestVO);

    /**
     *获取品牌商可充值话费
     * @param sysBrandId
     * @return
     */
    ResponseData getChargeGoodsList(String sysBrandId,String bizvaneSessionId);

    /**
     *获取手机号支持充值话费
     * @param sysBrandId
     * @param mobile
     * @return
     */
    ResponseData getChargeGoodsListByMobile(String sysBrandId,String mobile,String bizvaneSessionId);

    /**
     *获取历史充值号码
     * @param sysBrandId
     * @param memberCode
     * @return
     */
    ResponseData getHistoryChargeMobile(String sysBrandId,String memberCode);

    public ResponseData<IntegralOrderResponseVo> getOrderDetail(IntegralOrderRequestVo requestVo);

}

==> applet-service-2.0.2-20210623.080615-4-sources.jar: com/bizvane/appletservice/interfaces/IntegrationShopService.java <==
package com.bizvane.appletservice.interfaces;

import com.alibaba.fastjson.JSONObject;
import com.bizvane.appletservice.models.vo.*;
import com.bizvane.mktcenterservice.models.vo.CouponRecordVO;
import com.bizvane.utils.responseinfo.ResponseData;
import org.springframework.web.bind.annotation.RequestBody;

import java.io.IOException;
import java.util.Map;

/**
 * 积分商城
 *
 * @author gs
 * @date
 */
public interface IntegrationShopService {
    /**
     * 积分商城首页
     *
     * @param
     * @return
     **/
    ResponseData shopHomePage(String sysBrandId, String menberCode);

    ResponseData<ShopHomePageVo> getHomePageMemberInfo(String memberCode, Long sysBrandId);

    /**
     * 全部商品展示
     *
     * @param
     * @return
     **/
    ResponseData fullMerchandiseDisplay(AllMerchandiseVo allMerchandiseVo);

    /**
     * 商品详情
     *
     * @param
     * @return
     **/
    ResponseData commodityDetails(String hostId);

    /**
     * 分类商品入口
     *
     * @param
     * @return
     **/
    ResponseData classifiedGoods(classifiedGoodsVo classifiedGoodsVo);
    /**
     * 分类商品列表
     *
     * @param
     * @return
     **/
    ResponseData tailForClassifiedGoods(AllMerchandiseVo allMerchandiseVo);

    /**
     * 生成订单
     *
     * @param
     * @return
     **/
    ResponseData generateOrder(ConfirmGoodsVo confirmGoodsVo);

    /**
     * 效验订单生成
     *
     * @param
     * @return
     **/
    ResponseData inventoryStatus(ConfirmGoodsVo confirmGoodsVo);

    /**
     * 增加收货地址
     *
     * @param
     * @return
     **/
    ResponseData increaseReceivingAddress(UserAddressPutVo userAddressPutVo);

    /**
     * 编辑收货地址
     *
     * @param
     * @return
     **/
    ResponseData editReceivingAddress(UserAddressPutVo userAddressPutVo);

    /**
     * 删除收货地址
     *
     * @param
     * @return
     **/
    ResponseData eliminateReceivingAddress(UserAddressPutVo userAddressPutVo);

    /**
     * 地址查询
     *
     * @param
     * @return
     **/
    ResponseData  addressuery(String memberCode);

    /**
     * 订单列表
     *
     * @param
     * @return
     **/
    ResponseData fullOrderDisplay(String sysBrandId, String orderStatus, String memberCode,Integer pageNum,Integer pageSize);


    /**
     * (旧版)订单列表
     *
     * @param
     * @return
     **/
    ResponseData fullOrderDisplay(String sysBrandId, String orderStatus, String memberCode);

    /**
     * 查看订单
     *
     * @param
     * @return
     **/
    ResponseData viewOrder(String orderId);
    /**
     * 优惠券
     *
     * @param
     * @return
     **/
    ResponseData fullCouponDisplay(CouponRecordVO couponRecordVO);
    /**
     * 优惠券订单详情
     *
     * @param
     * @return
     **/
    ResponseData tailForFullCouponDisplay(Long convertCouponRecordId,String memberCode);


    /**
     * 获取积分
     *
     * @param
     * @return
     **/
    ResponseData integralAcquisition(String sysBrandId);

    /**
     * 门店自提
     *
     * @param
     * @return
     **/
    ResponseData storeSelfMention();
    /**
     * 物流公司列表
     *
     * @param
     * @return
     **/
    ResponseData logisticsCompanyGroup();
    /**
     * 查看物流
     *
     * @param
     * @return
     **/
    ResponseData displayLogistics(String companyCode,String num,String phone);

    /**
     * 申请退货提交
     *
     * @param
     * @return
     **/
    ResponseData applyeturnSubmission(ReturnGoodsVo returnGoodsVo);

    /**
     * 申请退货添加物流
     *
     * @param
     * @return
     **/
    ResponseData applyeturnNotSubmitted(RefundLogisticsVo refundLogisticsVo);
    /**
     * 获取退货说明
     *
     * @param
     * @return
     **/
    ResponseData instructions(String sysBrandId);

    /**
     * 获取基础配置
     * @param merchantId
     * @return
     */
    ResponseData getConfig(Integer merchantId) throws IOException;

    void setIntegralConfig2Redis(Map<String, Object> map, Integer merchantId) ;

    ResponseData getAllOrdersPages(int pageNum, int pageSize, Integer sysBrandId, String memberCode);

    /**
     * 支付
     * @param ordersId
     * @return
     */
    ResponseData  payment(Integer ordersId);

    /**
     * 支付券
     * @param convertCouponRecordId
     * @return
     */
    ResponseData  paymentWithCoupon(Integer convertCouponRecordId,String bizvaneSessionId);

    /**
     * 支付成功
     * @param convertCouponRecordId
     * @return
     */
    ResponseData  payCouponSuccess(Integer convertCouponRecordId);

    ResponseData getFeight(IntegralOrderFeightVO integralOrderFeightVO);

    ResponseData getIntegralClassifyQRCord(IntegralQRCodeRequestVO integralQRCodeRequestVO);
    /**
    * 获取首页轮播图,分类和券图
    * */
    ResponseData<ShopHomePageVo> getHomePageRotationChart(String sysBrandId);
    /**
     * 获取首页热门商品
     * */
    ResponseData<JSONObject> getHomePageHotCommodity(IntegralShopGetHomePageHotCommodityRequestVO requestVO);

    /**
     *获取品牌商可充值话费
     * @param sysBrandId
     * @return
     */
    ResponseData getChargeGoodsList(String sysBrandId,String bizvaneSessionId);

    /**
     *获取手机号支持充值话费
     * @param sysBrandId
     * @param mobile
     * @return
     */
    ResponseData getChargeGoodsListByMobile(String sysBrandId,String mobile,String bizvaneSessionId);

    /**
     *获取历史充值号码
     * @param sysBrandId
     * @param memberCode
     * @return
     */
    ResponseData getHistoryChargeMobile(String sysBrandId,String memberCode);

    public ResponseData<IntegralOrderResponseVo> getOrderDetail(IntegralOrderRequestVo requestVo);

    public ResponseData<Integer> sendPayedOrderMq(@RequestBody IntegralOrderSendMqRequestVo requestVo);

}
